==> nocc-1.9.1.tbz: www/nocc/lang/ps.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ps.php 2293 2010-10-18 19:00:53Z siebrand $
 */
/** Pashto (پښتو)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ahmed-Najib-Biabani-Ibrahimkhel
 */

$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$err_user_empty = 'د کارن نوم ځای تش دی';
$err_passwd_empty = 'د پټنوم ځای تش دی';
$alt_delete = 'ټاکلي پيغامونه ړنګول';
$alt_delete_one = 'پيغام ړنګول';
$alt_new_msg = 'نوي پيغامونه';
$alt_reply = 'ليکوال ته ځواب وييل';
$alt_reply_all = 'ټول ځوابول';
$alt_forward = 'وړاندې کول';
$alt_next = 'راتلونکی';
$alt_prev = 'پخوانی';
$title_next_page = 'راتلونکی مخ';
$title_prev_page = 'پخوانی مخ';
$title_next_msg = 'راتلونکی پيغام';
$title_prev_msg = 'پخوانی پيغام';
$html_welcome = '%1$s ته ښه راغلاست';
$html_login = 'ننوتل';
$html_user_label = 'کارن:';
$html_passwd_label = 'پټنوم:';
$html_submit = 'سپارل';
$html_help = 'لارښود';
$html_server_label = 'پالنګر:';
$html_retry = 'بيا هڅه کول';
$html_remember = 'امستنې په ياد ساتل';
$html_lang_label = 'ژبه:';
$html_msgperpage_label = 'په يوه مخ د پيغامونو شمېر:';
$html_preferences = 'غوره توبونه';
$html_full_name_label = 'بشپړ نوم:';
$html_email_address_label = 'برېښليک پته:';
$html_hide_addresses = 'پتې پټول';
$html_reply_to = 'ځواب اخيستونکی';
$html_use_signature = 'لاسليک کارول';
$html_signature = 'لاسليک';
$html_signature_label = 'لاسليک:';
$html_folders = 'پوښۍ';
$html_folders_create_failed = 'پوښۍ نه شي جوړېدلای!';
$html_folders_rename_failed = 'د پوښۍ نوم نه شي بدلېدلای!';
$html_folders_updated = 'پوښۍ اوسمهالې شوې';
$html_folder_rename = 'نوم بدلول';
$html_folder_create = 'نوې نومېدلې پوښۍ جوړول';
$html_folder_delete = 'ړنګول';
$html_folder_to = 'ترلاسه کوونکی';
$html_filter_remove = 'ړنګول';
$html_filter_body = 'د پيغام جوسه';
$html_filter_name = 'د چاڼګر نوم';
$html_select_one = '--يو وټاکۍ--';
$html_and = 'او';
$html_or = 'يا';
$html_move = 'لېږدول';
$html_copy = 'لمېسل';
$html_messages_to = 'ټاکلي پيغامونه ... ته';
$html_gotopage = 'مخ ته ورتلل';
$html_gotofolder = 'پوښۍ ته ورتلل';
$html_other_folders = 'د پوښۍ لړليک';
$html_page = 'مخ';
$html_of = 'د';
$html_inbox = 'راتلنبکس';
$html_new_msg = 'ليکل';
$html_reply = 'ځوابول';
$html_reply_short = 'ځوابي:';
$html_reply_all = 'ځوابول (ټولو ته)';
$html_forward = 'وړاندې کول';
$html_delete = 'ړنګول';
$html_new = 'نوی';
$html_mark = 'ړنګول';
$html_unknown = '[ناڅرګند]';
$html_attach_delete = 'ټاکل شوي ليري کول';
$html_sort = 'اوډل';
$html_from = 'رالېږونکی';
$html_from_label = 'لېږونکی:';
$html_subject = 'سکالو';
$html_subject_label = 'سکالو:';
$html_date = 'نېټه';
$html_date_label = 'نېټه:';
$html_sent_label = 'لېږلی:';
$html_wrote = 'وليکل';
$html_size = 'کچه';
$html_totalsize = 'ټولټال کچه';
$html_kb = 'کيلوبايټ';
$html_mb = 'مېګابايټ';
$html_gb = 'ګېګا بايټ';
$html_bytes = 'بايټونه';
$html_filename = 'د دوتنې نوم';
$html_to = 'اخيستونکی';
$html_to_label = 'اخيستونکی';
$html_cc = 'لمېسه';
$html_cc_label = 'لمېسه:';
$html_nosubject = 'بې سرليکه';
$html_send = 'لېږل';
$html_cancel = 'ناګارل';
$html_no_mail = 'پيغام نشته.';
$html_logout = 'وتل';
$html_msg = 'پيغام';
$html_msgs = 'پيغامونه';
$html_priority = 'لومړيتوب';
$html_priority_label = 'لومړيتوب:';
$html_normal = 'نورمال';
$html_select = 'ټاکل';
$html_select_all = 'ټاکلي سرچپه کول';
$html_select_contacts = 'اړيکې ټاکل';
$html_loading_image = 'انځور برسېرول';
$html_read = 'لوستل';
$html_unread = 'نالوستل';
$html_add = 'ورګډول';
$html_contact_add = 'نوې اړيکه ورګډول';
$html_contact_first = 'لومړی نوم';
$html_contact_last = 'وروستی نوم';
$html_contact_mail = 'برېښليک';
$html_contact_list = 'د %1$s د اړيکو لړليک';
$html_contact_count = 'د %1$d اړيکې';
$html_contact_err2 = 'تاسې يوه نوې اړيکه نه شی ورګډولای';
$html_del_msg = 'آيا ټاکلي پيغامونه ړنګول غواړۍ؟';
$html_down_mail = 'ښکته کول';
$original_msg = '-- آرنی پيغام --';
$html_images_display = 'انځورونه ښکاره کول';
$html_invalid_email_address = 'ناسمه برېښليک پته';
$html_search = 'پلټل';

==> nocc-1.9.3.tbz: www/nocc/lang/ps.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: ps.php 2523 2011-12-03 11:41:12Z siebrand $
 */
/** Pashto (پښتو)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ahmed-Najib-Biabani-Ibrahimkhel
 */

$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y-%m-%d';
$err_user_empty = 'د کارن نوم ځای تش دی';
$err_passwd_empty = 'د پټنوم ځای تش دی';
$alt_delete = 'ټاکلي پيغامونه ړنګول';
$alt_delete_one = 'پيغام ړنګول';
$alt_new_msg = 'نوي پيغامونه';
$alt_reply = 'ليکوال ته ځواب وييل';
$alt_reply_all = 'ټول ځوابول';
$alt_forward = 'وړاندې کول';
$alt_next = 'راتلونکی';
$alt_prev = 'پخوانی';
$title_next_page = 'راتلونکی مخ';
$title_prev_page = 'پخوانی مخ';
$title_next_msg = 'راتلونکی پيغام';
$title_prev_msg = 'پخوانی پيغام';
$html_welcome = '%1$s ته ښه راغلاست';
$html_login = 'ننوتل';
$html_user_label = 'کارن:';
$html_passwd_label = 'پټنوم:';
$html_submit = 'سپارل';
$html_help = 'لارښود';
$html_server_label = 'پالنګر:';
$html_retry = 'بيا هڅه کول';
$html_remember = 'امستنې په ياد ساتل';
$html_lang_label = 'ژبه:';
$html_msgperpage_label = 'په يوه مخ د پيغامونو شمېر:';
$html_preferences = 'غوره توبونه';
$html_full_name_label = 'بشپړ نوم:';
$html_email_address_label = 'برېښليک پته:';
$html_hide_addresses = 'پتې پټول';
$html_reply_to = 'ځواب اخيستونکی';
$html_reply_to_label = 'ځواب اخيستونکی:';
$html_use_signature = 'لاسليک کارول';
$html_signature = 'لاسليک';
$html_signature_label = 'لاسليک:';
$html_colored_quotes = 'رنګينې وراشې';
$html_send_html_mail = 'برېښليک د HTML په بڼه لېږل';
$html_folders = 'پوښۍ';
$html_folders_create_failed = 'پوښۍ نه شي جوړېدلای!';
$html_folders_rename_failed = 'د پوښۍ نوم نه شي بدلېدلای!';
$html_folders_updated = 'پوښۍ اوسمهالې شوې';
$html_folder_rename = 'نوم بدلول';
$html_folder_create = 'نوې نومېدلې پوښۍ جوړول';
$html_folder_delete = 'ړنګول';
$html_folder_to = 'ترلاسه کوونکی';
$html_filter_remove = 'ړنګول';
$html_filter_body = 'د پيغام جوسه';
$html_filter_subject = 'د پيغام موضوع';
$html_filter_name = 'د چاڼګر نوم';
$html_select_one = '--يو وټاکۍ--';
$html_and = 'او';
$html_or = 'يا';
$html_move = 'لېږدول';
$html_copy = 'لمېسل';
$html_messages_to = 'ټاکلي پيغامونه ... ته';
$html_gotopage = 'مخ ته ورتلل';
$html_gotofolder = 'پوښۍ ته ورتلل';
$html_other_folders = 'د پوښۍ لړليک';
$html_page = 'مخ';
$html_of = 'د';
$html_inbox = 'ليکبکس';
$html_new_msg = 'ليکل';
$html_reply = 'ځوابول';
$html_reply_short = 'ځوابي:';
$html_reply_all = 'ځوابول (ټولو ته)';
$html_forward = 'وړاندې کول';
$html_delete = 'ړنګول';
$html_new = 'نوی';
$html_mark = 'ړنګول';
$html_unknown = '[ناڅرګند]';
$html_attach = 'ضميمه کول';
$html_attach_delete = 'ټاکل شوي ليري کول';
$html_sort = 'اوډل';
$html_from = 'رالېږونکی';
$html_from_label = 'لېږونکی:';
$html_subject = 'سکالو';
$html_subject_label = 'سکالو:';
$html_date = 'نېټه';
$html_date_label = 'نېټه:';
$html_sent_label = 'لېږلی:';
$html_wrote = 'وليکل';
$html_size = 'کچه';
$html_totalsize = 'ټولټال کچه';
$html_kb = 'کيلوبايټ';
$html_mb = 'مېګابايټ';
$html_gb = 'ګېګا بايټ';
$html_bytes = 'بايټونه';
$html_filename = 'د دوتنې نوم';
$html_to = 'اخيستونکی';
$html_to_label = 'اخيستونکی';
$html_cc = 'لمېسه';
$html_cc_label = 'لمېسه:';
$html_nosubject = 'بې سرليکه';
$html_send = 'لېږل';
$html_cancel = 'ناګارل';
$html_no_mail = 'پيغام نشته.';
$html_logout = 'وتل';
$html_msg = 'پيغام';
$html_msgs = 'پيغامونه';
$html_priority = 'لومړيتوب';
$html_priority_label = 'لومړيتوب:';
$html_normal = 'نورمال';
$html_select = 'ټاکل';
$html_select_all = 'ټاکلي سرچپه کول';
$html_select_contacts = 'اړيکې ټاکل';
$html_loading_image = 'انځور برسېرول';
$html_read = 'لوستل';
$html_unread = 'نالوستل';
$html_add = 'ورګډول';
$html_contacts = 'د %1$s اړيکې';
$html_contact_add = 'نوې اړيکه ورګډول';
$html_contact_first = 'لومړی نوم';
$html_contact_last = 'وروستی نوم';
$html_contact_mail = 'برېښليک';
$html_contact_list = 'د %1$s د اړيکو لړليک';
$html_contact_count = 'د %1$d اړيکې';
$html_contact_err2 = 'تاسې يوه نوې اړيکه نه شی ورګډولای';
$html_contact_none = 'هېڅ اړيکې و نه موندل شوې.';
$html_del_msg = 'آيا ټاکلي پيغامونه ړنګول غواړۍ؟';
$html_down_mail = 'ښکته کول';
$original_msg = '-- آرنی پيغام --';
$html_images_display = 'انځورونه ښکاره کول';
$html_invalid_email_address = 'ناسمه برېښليک پته';
$html_search = 'پلټل';
